@@ -5,7 +5,7 @@ Simple diffusion equation
 This example solves a simple diffusion equation in two dimensions.
 """
 
-from pde import DiffusionPDE, UnitGrid, ScalarField
+from pde import DiffusionPDE, ScalarField, UnitGrid
 
 grid = UnitGrid([64, 64])  # generate grid
 state = ScalarField.random_uniform(grid, 0.2, 0.3)  # generate initial condition
