@@ -15,7 +15,7 @@ from ..grids.base import GridBase
 from ..tools.docstrings import fill_in_docstring
 from ..tools.misc import Number, number_array
 from ..tools.plotting import PlotReference, plot_on_figure
-from ..tools.typing import ArrayLike
+from ..tools.typing import ArrayLike, NumberOrArray
 from .base import DataFieldBase, FieldBase
 from .scalar import ScalarField
 
@@ -158,31 +158,40 @@ class FieldCollection(FieldBase):
             for field in self.fields:
                 if field.label == index:
                     return field
-            raise KeyError(f"No field with name {index}")
+            raise KeyError(f"No field with name `{index}`")
 
         else:
-            raise TypeError(f"Unsupported index {index}")
+            raise TypeError(f"Unsupported index `{index}`")
 
-    def __setitem__(self, index: int, value):
-        """ set the value of a specific field """
+    def __setitem__(self, index: Union[int, str], value: NumberOrArray):
+        """set the value of a specific field
+
+        Args:
+            index (int or str):
+                Determines which field is updated. If `index` is an integer it specifies
+                the position of the field that will be updated. If `index` is a string,
+                the first field with this name will be updated.
+            value (float or :class:`~numpy.ndarray`):
+                The updated value(s) of the chosen field.
+        """
         # We need to load the field and set data explicitly
         # WARNING: Do not use `self.fields[index] = value`, since this would
         # break the connection between the data fields
         if isinstance(index, int):
             # simple numerical index
-            self.fields[index].data = value
+            self.fields[index].data = value  # type: ignore
 
         elif isinstance(index, str):
             # index specifying the label of the field
             for field in self.fields:
                 if field.label == index:
-                    field.data = value
-                    break
+                    field.data = value  # type: ignore
+                    break  # indicates that a field has been found
             else:
-                raise KeyError(f"No field with name {index}")
+                raise KeyError(f"No field with name `{index}`")
 
         else:
-            raise TypeError(f"Unsupported index {index}")
+            raise TypeError(f"Unsupported index `{index}`")
 
     @property
     def fields(self) -> List[DataFieldBase]:
@@ -342,7 +351,7 @@ class FieldCollection(FieldBase):
         vmax: float = 1,
         label: Optional[str] = None,
         labels: Optional[Sequence[str]] = None,
-    ):
+    ) -> "FieldCollection":
         """create scalar fields with random values between `vmin` and `vmax`
 
         Args:
@@ -434,7 +443,9 @@ class FieldCollection(FieldBase):
     def interpolate_to_grid(
         self,
         grid: GridBase,
-        method: str = "numba",
+        *,
+        backend: str = "numba",
+        method: str = "linear",
         fill: Number = None,
         label: Optional[str] = None,
     ) -> "FieldCollection":
@@ -444,9 +455,13 @@ class FieldCollection(FieldBase):
             grid (:class:`~pde.grids.GridBase`):
                 The grid of the new field onto which the current field is
                 interpolated.
+            backend (str):
+                The accepted values `scipy` and `numba` determine the backend that is
+                used for the interpolation.
             method (str):
-                Specifies interpolation method, e.g., 'numba', 'scipy_linear',
-                'scipy_nearest' .
+                Determines the method being used for interpolation. Typical values that
+                are `nearest` and `linear, but the supported values depend on the chosen
+                `backend.
             fill (Number, optional):
                 Determines how values out of bounds are handled. If `None`, a
                 `ValueError` is raised when out-of-bounds points are requested.
@@ -460,13 +475,15 @@ class FieldCollection(FieldBase):
         if label is None:
             label = self.label
         fields = [
-            f.interpolate_to_grid(grid, method=method, fill=fill) for f in self.fields
+            f.interpolate_to_grid(grid, backend=backend, method=method, fill=fill)
+            for f in self.fields
         ]
         return self.__class__(fields, label=label)
 
     def smooth(
         self,
         sigma: float = 1,
+        *,
         out: Optional["FieldCollection"] = None,
         label: str = None,
     ) -> "FieldCollection":
@@ -652,7 +669,9 @@ class FieldCollection(FieldBase):
         # plot all the elements onto the respective axes
         reference = [
             field.plot(kind=knd, ax=ax, action="create", **kwargs, **sp_args)
-            for field, knd, ax, sp_args in zip(self.fields, kind, axs, subplot_args)
+            for field, knd, ax, sp_args in zip(
+                self.fields, kind, axs, subplot_args
+            )  # @UnusedVariable
         ]
 
         # return the references for all subplots
@@ -697,7 +716,7 @@ class _FieldLabels:
     def __eq__(self, other):
         return list(self) == list(other)
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator[Optional[str]]:
         for field in self.collection:
             yield field.label
 
@@ -717,8 +736,7 @@ class _FieldLabels:
     ):
         """ change one or many labels of a field in the collection """
         if isinstance(index, int):
-            assert isinstance(value, str)
-            self.collection.fields[index].label = value
+            self.collection.fields[index].label = value  # type: ignore
         elif isinstance(index, slice):
             fields = self.collection.fields[index]
             if value is None or isinstance(value, str):
@@ -729,3 +747,18 @@ class _FieldLabels:
                 field.label = label
         else:
             raise TypeError("Unsupported index type")
+
+    def index(self, label: str) -> int:
+        """return the index in the field labels where a certain label is stored
+
+        Args:
+            label (str):
+                The label that is sought
+
+        Returns:
+            int: The index in the list (or `ValueError` if it cannot be found)
+        """
+        for i, field in enumerate(self.collection):
+            if field.label == label:
+                return i
+        raise ValueError(f"Label `{label}` is not present in the collection")
