@@ -74,12 +74,14 @@ class CahnHilliardPDE(PDEBase):
             :class:`~pde.fields.ScalarField`:
             Scalar field describing the evolution rate of the PDE
         """
-        assert isinstance(state, ScalarField)
+        assert isinstance(state, ScalarField), "`state` must be ScalarField"
         c_laplace = state.laplace(bc=self.bc_c, label="evolution rate")
         result = state ** 3 - state - self.interface_width * c_laplace
         return result.laplace(bc=self.bc_mu)  # type: ignore
 
-    def _make_pde_rhs_numba(self, state: ScalarField) -> Callable:  # type: ignore
+    def _make_pde_rhs_numba(  # type: ignore
+        self, state: ScalarField
+    ) -> Callable[[np.ndarray, float], np.ndarray]:
         """create a compiled function evaluating the right hand side of the PDE
 
         Args:
