@@ -83,13 +83,15 @@ class KPZInterfacePDE(PDEBase):
             :class:`~pde.fields.ScalarField`:
             Scalar field describing the evolution rate of the PDE
         """
-        assert isinstance(state, ScalarField)
+        assert isinstance(state, ScalarField), "`state` must be ScalarField"
         result = self.nu * state.laplace(bc=self.bc)
         result += self.lmbda * state.gradient_squared(bc=self.bc)
         result.label = "evolution rate"
         return result  # type: ignore
 
-    def _make_pde_rhs_numba(self, state: ScalarField) -> Callable:  # type: ignore
+    def _make_pde_rhs_numba(  # type: ignore
+        self, state: ScalarField
+    ) -> Callable[[np.ndarray, float], np.ndarray]:
         """create a compiled function evaluating the right hand side of the PDE
 
         Args:
