@@ -83,7 +83,7 @@ class KuramotoSivashinskyPDE(PDEBase):
             :class:`~pde.fields.ScalarField`:
             Scalar field describing the evolution rate of the PDE
         """
-        assert isinstance(state, ScalarField)
+        assert isinstance(state, ScalarField), "`state` must be ScalarField"
         state_lap = state.laplace(bc=self.bc)
         result = (
             -self.nu * state_lap.laplace(bc=self.bc_lap)
@@ -93,7 +93,9 @@ class KuramotoSivashinskyPDE(PDEBase):
         result.label = "evolution rate"
         return result  # type: ignore
 
-    def _make_pde_rhs_numba(self, state: ScalarField) -> Callable:  # type: ignore
+    def _make_pde_rhs_numba(  # type: ignore
+        self, state: ScalarField
+    ) -> Callable[[np.ndarray, float], np.ndarray]:
         """create a compiled function evaluating the right hand side of the PDE
 
         Args:
