@@ -6,7 +6,7 @@ Defines a PDE class whose right hand side is given as a string
 
 import re
 from collections import OrderedDict
-from typing import Any, Callable, Dict
+from typing import Any, Callable, Dict, Tuple
 
 import numpy as np
 
@@ -243,11 +243,11 @@ class PDE(PDEBase):
         if "dot" in self.diagnostics["operators"]:  # type: ignore
             # add dot product between two vector fields. This can for instance
             # appear when two gradients of scalar fields need to be multiplied
-            ops_general["dot"] = VectorField(state.grid).make_dot_operator()
+            ops_general["dot"] = VectorField(state.grid).make_dot_operator(backend)
 
         if "inner" in self.diagnostics["operators"]:  # type: ignore
             # synonym for dot product operator
-            ops_general["inner"] = VectorField(state.grid).make_dot_operator()
+            ops_general["inner"] = VectorField(state.grid).make_dot_operator(backend)
 
         if "outer" in self.diagnostics["operators"]:  # type: ignore
             # synonym for dot product operator
@@ -279,15 +279,14 @@ class PDE(PDEBase):
                     ops[func] = state.grid.get_operator(func, bc=bc)
                 except ValueError:
                     self._logger.info(
-                        "Operator %s was not defined, so we assume that sympy knows it",
-                        func,
+                        "Assuming that sympy knows undefined operator `%s`", func
                     )
 
             # obtain the function to calculate the right hand side
             expr = self._rhs_expr[var]
             signature = self.variables + ("t",)
 
-            def _get_expr_func(signature):
+            def _get_expr_func(signature: Tuple[str, ...]) -> Callable[..., np.ndarray]:
                 """ helper function obtaining expression and checking the signature """
                 extra_vars = set(expr.vars) - set(signature)
                 if extra_vars:
@@ -304,20 +303,22 @@ class PDE(PDEBase):
                     )
                 else:
                     raise ValueError(f"Unsupported backend {backend}")
-                return result
+                return result  # type: ignore
 
             if any(expr.depends_on(c) for c in state.grid.axes):
                 # expression has a spatial dependence, too
 
                 # determine and check the signature
-                inner_func = jit(_get_expr_func(signature + tuple(state.grid.axes)))
+                inner_func = _get_expr_func(signature + tuple(state.grid.axes))
+                if backend == "numba":
+                    inner_func = jit(inner_func)
 
                 # inject the spatial coordinates into the expression for the rhs
                 coords_tuple = tuple(  # @UnusedVariable
                     state.grid.cell_coords[..., i] for i in range(state.grid.num_axes)
                 )
 
-                def rhs_func(*args):
+                def rhs_func(*args) -> np.ndarray:
                     """ wrapper that inserts the spatial variables """
                     return inner_func(*args, *coords_tuple)
 
@@ -336,7 +337,7 @@ class PDE(PDEBase):
             starts = tuple(slc.start for slc in state._slices)
             stops = tuple(slc.stop for slc in state._slices)
 
-            def get_data_tuple(state_data):
+            def get_data_tuple(state_data: np.ndarray) -> Tuple[np.ndarray, ...]:
                 """ helper for turning state_data into a tuple of field data """
                 return tuple(
                     state_data[starts[i]]
@@ -387,7 +388,7 @@ class PDE(PDEBase):
 
     def _make_pde_rhs_numba_coll(
         self, state: FieldCollection, cache: Dict[str, Any]
-    ) -> Callable:
+    ) -> Callable[[np.ndarray, float], np.ndarray]:
         """create the compiled rhs if `state` is a field collection
 
         Args:
@@ -420,7 +421,9 @@ class PDE(PDEBase):
 
         get_data_tuple = cache["get_data_tuple"]
 
-        def chain(i=0, inner=None):
+        def chain(
+            i: int = 0, inner: Callable[[np.ndarray, float, np.ndarray], None] = None
+        ) -> Callable[[np.ndarray, float], np.ndarray]:
             """ recursive helper function for applying all rhs """
             # run through all functions
             rhs = rhs_list[i]
@@ -428,14 +431,14 @@ class PDE(PDEBase):
             if inner is None:
                 # the innermost function does not need to call a child
                 @jit
-                def wrap(data_tpl, t, out):
+                def wrap(data_tpl: np.ndarray, t: float, out: np.ndarray):
                     out[starts[i] : stops[i]] = rhs(*data_tpl, t)
 
             else:
                 # all other functions need to call one deeper in the chain
                 @jit
-                def wrap(data_tpl, t, out):
-                    inner(data_tpl, t, out)
+                def wrap(data_tpl: np.ndarray, t: float, out: np.ndarray):
+                    inner(data_tpl, t, out)  # type: ignore
                     out[starts[i] : stops[i]] = rhs(*data_tpl, t)
 
             if i < num_fields - 1:
@@ -444,19 +447,21 @@ class PDE(PDEBase):
             else:
                 # this is the outermost function
                 @jit
-                def evolution_rate(state_data: np.ndarray, t: float = 0):
+                def evolution_rate(state_data: np.ndarray, t: float = 0) -> np.ndarray:
                     out = np.empty(data_shape)
                     with nb.objmode():
                         data_tpl = get_data_tuple(state_data)
                         wrap(data_tpl, t, out)
                     return out
 
-                return evolution_rate
+                return evolution_rate  # type: ignore
 
         # compile the recursive chain
-        return chain()  # type: ignore
+        return chain()
 
-    def _make_pde_rhs_numba(self, state: FieldBase) -> Callable:
+    def _make_pde_rhs_numba(
+        self, state: FieldBase
+    ) -> Callable[[np.ndarray, float], np.ndarray]:
         """create a compiled function evaluating the right hand side of the PDE
 
         Args:
