@@ -90,7 +90,7 @@ class SwiftHohenbergPDE(PDEBase):
             :class:`~pde.fields.ScalarField`:
             Scalar field describing the evolution rate of the PDE
         """
-        assert isinstance(state, ScalarField)
+        assert isinstance(state, ScalarField), "`state` must be ScalarField"
         state_laplace = state.laplace(bc=self.bc)
         state_laplace2 = state_laplace.laplace(bc=self.bc_lap)
 
@@ -104,7 +104,9 @@ class SwiftHohenbergPDE(PDEBase):
         result.label = "evolution rate"
         return result  # type: ignore
 
-    def _make_pde_rhs_numba(self, state: ScalarField) -> Callable:  # type: ignore
+    def _make_pde_rhs_numba(  # type: ignore
+        self, state: ScalarField
+    ) -> Callable[[np.ndarray, float], np.ndarray]:
         """create a compiled function evaluating the right hand side of the PDE
 
         Args:
