@@ -197,7 +197,7 @@ class MemoryStorage(StorageBase):
             data (:class:`~numpy.ndarray`): The actual data
             time (float, optional): The time point associated with the data
         """
-        assert data.shape == self.data_shape
+        assert data.shape == self.data_shape, f"Data must have shape {self.data_shape}"
         self.data.append(np.array(data))  # store copy of the data
         self.times.append(time)
 
