@@ -1,15 +1,14 @@
 """
-.. codeauthor:: David Zwicker <dzwicker@seas.harvard.edu>
+.. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de>
 """
 
-from __future__ import division
-
 import collections
 import copy
 import sys
 
 import numpy as np
 import pytest
+
 from pde.tools import cache
 
 
