@@ -1,9 +1,10 @@
 """
-.. codeauthor:: David Zwicker <dzwicker@seas.harvard.edu>
+.. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de>
 """
 
 import numpy as np
 import pytest
+
 from pde.tools.cuboid import Cuboid, asanyarray_flags
 
 
@@ -108,10 +109,10 @@ def test_asanyarray_flags():
     assert a is asanyarray_flags(a)
     assert a is asanyarray_flags(a, np.double)
     assert a is asanyarray_flags(a, writeable=True)
-    assert a is not asanyarray_flags(a, np.int)
+    assert a is not asanyarray_flags(a, np.intc)
     assert a is not asanyarray_flags(a, writeable=False)
 
-    for dtype in (np.int, np.double):
+    for dtype in (np.intc, np.double):
         b = asanyarray_flags(a, dtype)
         assert b.dtype == dtype
 
