@@ -37,7 +37,8 @@ from ..tools.docstrings import fill_in_docstring
 from ..tools.misc import module_available
 from ..tools.output import get_progress_bar_class
 from ..tools.parse_duration import parse_duration
-from .base import FinishedSimulation, InfoDict, Real, TrackerBase
+from ..tools.typing import Real
+from .base import FinishedSimulation, InfoDict, TrackerBase
 from .intervals import IntervalData, RealtimeIntervals
 
 if TYPE_CHECKING:
@@ -53,13 +54,14 @@ class CallbackTracker(TrackerBase):
     def __init__(self, func: Callable, interval: IntervalData = 1):
         """
         Args:
-            func: The function to call periodically. The function signature
-                should be `(state)` or `(state, time)`, where `state` contains
-                the current state as an instance of
-                :class:`~pde.fields.FieldBase` and `time` is a
-                float value indicating the current time. Note that only a view
-                of the state is supplied, implying that a copy needs to be made
-                if the data should be stored.
+            func: The function to call periodically. The function signature should be
+                `(state)` or `(state, time)`, where `state` contains the current state
+                as an instance of :class:`~pde.fields.base.FieldBase` and `time` is a
+                float value indicating the current time. Note that only a view of the
+                state is supplied, implying that a copy needs to be made if the data
+                should be stored. The function can thus adjust the state by modifying it
+                in-place and it can even interrupt the simulation by raising the special
+                exception :class:`StopIteration`.
             interval:
                 {ARG_TRACKER_INTERVAL}
         """
@@ -188,7 +190,7 @@ class ProgressTracker(TrackerBase):
             # progress bar) since reaching steady state means the simulation
             # was successful even though it did not reach t_final
             try:
-                self.progress_bar.sp(bar_style="success")
+                self.progress_bar.sp(bar_style="success")  # type: ignore
             except TypeError:
                 self.progress_bar.close()
             else:
@@ -642,9 +644,10 @@ class SteadyStateTracker(TrackerBase):
         self.rtol = rtol
         self.progress = progress and module_available("tqdm")
 
-        self._last_data = None
-        self._best_diff_first = None
-        self._best_diff_max = None
+        self._progress_bar: Any = None
+        self._pbar_offset: float = 0  # required for calculating progress
+        self._last_data: Optional[np.ndarray] = None
+        self._best_diff_max: Optional[np.ndarray] = None
 
     def handle(self, field: FieldBase, t: float) -> None:
         """handle data supplied to this tracker
