@@ -202,7 +202,7 @@ class ScalarFieldPlot:
             :class:`~pde.visualization.plotting.ScalarFieldPlot`
         """
         fields = storage[0]
-        assert isinstance(fields, FieldBase)
+        assert isinstance(fields, FieldBase), "Storage must contain fields"
 
         # prepare the data that needs to be plotted
         quantities = cls._prepare_quantities(fields, quantities=quantities, scale=scale)
@@ -392,7 +392,7 @@ class ScalarFieldPlot:
                 The title of this view. If `None`, the current title is not
                 changed.
         """
-        assert isinstance(fields, FieldBase)
+        assert isinstance(fields, FieldBase), "Fields must inherit from FieldBase"
 
         if title:
             self.sup_title.set_text(title)
@@ -519,7 +519,7 @@ def plot_magnitudes(
     """
     if quantities is None:
         fields = storage[0]
-        assert isinstance(fields, FieldBase)
+        assert isinstance(fields, FieldBase), "Storage must contain fields"
         if fields.label:
             label_base = fields.label
         else:
